@@ -29,7 +29,7 @@
 #' @param stylized logical. Should DAG nodes be stylized? If so, use
 #'   `geom_dag_nodes` and if not use `geom_dag_point`
 #' @param text logical. Should text be included in the DAG?
-#' @param use_labels a string. Variable to use for `geom_dag_repel_label()`.
+#' @param use_labels a string. Variable to use for `geom_dag_label_repel()`.
 #'   Default is `NULL`.
 #' @param spread the width of the fan spread
 #'
@@ -53,11 +53,11 @@
 dag_paths <- function(.dag, from = NULL, to = NULL, adjust_for = NULL, limit = 100, directed = FALSE, paths_only = FALSE, ...) {
   .tdy_dag <- if_not_tidy_daggity(.dag, ...)
 
-  if (is.null(from)) from <- dagitty::exposures(.tdy_dag$dag)
-  if (is.null(to)) to <- dagitty::outcomes(.tdy_dag$dag)
+  if (is.null(from)) from <- dagitty::exposures(pull_dag(.tdy_dag))
+  if (is.null(to)) to <- dagitty::outcomes(pull_dag(.tdy_dag))
   if (is.null(from) || is.null(to)) stop("`exposure` and `outcome` must be set!")
 
-  pathways <- dagitty::paths(.tdy_dag$dag, from, to, Z = adjust_for, limit = limit, directed = directed) %>%
+  pathways <- dagitty::paths(pull_dag(.tdy_dag), from, to, Z = adjust_for, limit = limit, directed = directed) %>%
     dplyr::as_tibble() %>%
     dplyr::filter(open) %>%
     dplyr::pull(paths)
@@ -65,7 +65,7 @@ dag_paths <- function(.dag, from = NULL, to = NULL, adjust_for = NULL, limit = 1
 
   vars <- c(from = from, to = to)
 
-  .tdy_dag$data <- pathways %>%
+  update_dag_data(.tdy_dag) <- pathways %>%
     purrr::map_df(function(.x) {
       path_df <- .x %>%
         dag2() %>%
@@ -76,7 +76,7 @@ dag_paths <- function(.dag, from = NULL, to = NULL, adjust_for = NULL, limit = 1
           .to = as.character(.to),
           path = "open path"
         ) %>%
-        ggdag_left_join(.tdy_dag$data, ., by = c("name" = ".from", "to" = ".to"))
+        ggdag_left_join(pull_dag_data(.tdy_dag), ., by = c("name" = ".from", "to" = ".to"))
 
       any_x_unopend <- any(path_df$name == vars[[1]] & is.na(path_df$path))
       if (any_x_unopend) {
@@ -107,7 +107,7 @@ dag_paths <- function(.dag, from = NULL, to = NULL, adjust_for = NULL, limit = 1
       path_df
     }, .id = "set")
 
-  if (paths_only) .tdy_dag$data <- filter(.tdy_dag$data, path == "open path")
+  if (paths_only) .tdy_dag <- dplyr::filter(.tdy_dag, path == "open path")
 
   .tdy_dag
 }
